## 🔧 Changes

### Drop Python 3.9 and earlier support

The minimum Python version is now 3.10. Also includes various CI fixes and repository URL corrections.

*By @mavam.*

### Remove Python 3.10 and 3.11 support

The minimum Python version is now 3.12. The CI test matrix now covers Python 3.12 and 3.13.

*By @mavam and @claude.*
